@@ -6,7 +6,7 @@ from .protocolHandler import *
 from . import LOGGER
 import time
 
-tarVersion = "V20220415"
+tarVersion = "V20220718"
 
 VersionDetail = "当前版本:" + tarVersion + """
 ---------------------------版本更新信息----------------------------
@@ -21,6 +21,9 @@ V20220415:
 2. 添加了直接打开/关闭5V输出接口的方法。
 3. 添加了更为详细的API说明和使用示例。
 
+V20220718:
+1. 修复了语音识别编码字典(voiceEncodeV3)与硬件返回不匹配的BUG。
+
 ------------------------------------------------------------------
 """
 
@@ -29,6 +32,7 @@ class GeneralDeviceDict():
     last_speech = 0xFF
     voiceEncodeV3 = {
         0: "未识别到语音",
+        223: "再见",
         1: "小飞同学",
         2: "打开灯光",
         3: "关闭灯光",
@@ -43,8 +47,8 @@ class GeneralDeviceDict():
         85: "蓝色模式",
         86: "彩色模式",
         87: "流水灯模式",
-        90: "打开报警",
-        91: "关闭报警",
+        90: "打开警报",
+        91: "关闭警报",
         121: "你好",
         122: "打开门",
         123: "关闭门",
@@ -53,12 +57,12 @@ class GeneralDeviceDict():
         126: "音量增",
         127: "我回来了",
         128: "我出去了",
-        133: "开始",
-        134: "结束",
-        135: "前进",
-        136: "后退",
-        137: "左转",
-        138: "右转",
+        141: "开始",
+        142: "结束",
+        143: "前进",
+        144: "后退",
+        145: "左转",
+        146: "右转",
     }
     colorEncode = {
         0: "无",
